@@ -38,18 +38,30 @@ const QByteArray SageSession::SageAlternativePrompt="....: "; //Text, sage outpu
 static QByteArray initCmd="os.environ['PAGER'] = 'cat'                     \n "\
                            "sage.misc.pager.EMBEDDED_MODE = True           \n "\
                            "sage.misc.viewer.BROWSER=''                    \n "\
+                           "sage.misc.viewer.viewer.png_viewer('')         \n" \
                            "sage.plot.plot3d.base.SHOW_DEFAULTS['viewer'] = 'tachyon' \n"\
                            "sage.misc.latex.EMBEDDED_MODE = True           \n "\
                            "os.environ['PAGER'] = 'cat'                    \n "\
-                           " __IPYTHON__.shell.autoindent=False            \n "\
-                           "print '____TMP_DIR____', sage.misc.misc.SAGE_TMP\n"\
-                           "print '____END_OF_INIT____'                    \n ";
+                           "%colors nocolor                                \n "\
+                           "print '____TMP_DIR____', sage.misc.misc.SAGE_TMP\n";
+
+static QByteArray newInitCmd=
+    "__CANTOR_IPYTHON_SHELL__=get_ipython()   \n "\
+    "__CANTOR_IPYTHON_SHELL__.autoindent=False\n "\
+    "print '____END_OF_INIT____'              \n ";
+
+static QByteArray legacyInitCmd=
+    "__CANTOR_IPYTHON_SHELL__=__IPYTHON__   \n "  \
+    "__CANTOR_IPYTHON_SHELL__.autoindent=False\n "\
+    "print '____END_OF_INIT____'              \n ";
+
 
 SageSession::SageSession( Cantor::Backend* backend) : Session(backend)
 {
     kDebug();
     m_isInitialized=false;
-
+    m_inLegacyMode=false;
+    m_haveSentInitCmd=false;
     connect( &m_dirWatch, SIGNAL( created( const QString& ) ), this, SLOT( fileCreated( const QString& ) ) );
 }
 
@@ -129,9 +141,48 @@ void SageSession::readStdOut()
 
         kDebug()<<"tmp path: "<<m_tmpPath;
 
-        m_dirWatch.addDir( m_tmpPath, KDirWatch::WatchFiles );
+        m_dirWatch.addDir( m_tmpPath, KDirWatch::WatchFiles );     
     }
 
+    if(!m_isInitialized)
+    {
+        //try to guess the version of sage to determine
+        //if we have to use the legacy commands or not.
+        QRegExp versionExp("Sage\\s+Version\\s+(\\d+)\\.(\\d+)");
+        int index=versionExp.indexIn(m_outputCache);
+        if(index!=-1)
+        {
+            QStringList version=versionExp.capturedTexts();
+            kDebug()<<"found version: "<<version;
+            if(version.size()>2)
+            {
+                int major=version[1].toInt();
+                int minor=version[2].toInt();
+            
+                if(major<=5&&minor<=7)
+                {
+                    m_inLegacyMode=true;
+                    kDebug()<<"using an old version of sage: "<<major<<"."<<minor<<". switching to legacy mode";
+                    if(!m_haveSentInitCmd)
+                    {
+                        m_process->pty()->write(legacyInitCmd);
+                        m_haveSentInitCmd=true;
+                    }
+
+                }else
+                {
+                    kDebug()<<"using the current set of commands";
+                    if(!m_haveSentInitCmd)
+                    {
+                        m_process->pty()->write(newInitCmd);
+                        m_haveSentInitCmd=true;
+                    }
+                }
+            }
+        }
+    }
+    
+
     int indexOfEOI=m_outputCache.indexOf("____END_OF_INIT____");
     if(indexOfEOI!=-1&&m_outputCache.indexOf(SagePrompt, indexOfEOI)!=-1)
     {
@@ -277,6 +328,7 @@ void SageSession::waitForNextPrompt()
 
 void SageSession::fileCreated( const QString& path )
 {
+    kDebug()<<"got a file "<<path;
     SageExpression* expr=m_expressionQueue.first();
     if ( expr )
         expr->addFileResult( path );
@@ -285,14 +337,23 @@ void SageSession::fileCreated( const QString& path )
 void SageSession::setTypesettingEnabled(bool enable)
 {
     Cantor::Session::setTypesettingEnabled(enable);
-
     //tell the sage server to enable/disable pretty_print
-    //the _ and __IP.outputcache() are needed to keep the
-    // _ operator working
-    if (enable)
-        evaluateExpression("sage.misc.latex.pretty_print_default(true);_;__IP.outputcache()", Cantor::Expression::DeleteOnFinish);
-    else
-        evaluateExpression("sage.misc.latex.pretty_print_default(false);_;__IP.outputcache()", Cantor::Expression::DeleteOnFinish);
+    if(inLegacyMode())
+    {
+        //the _ and __IP.outputcache() are needed to keep the
+        // _ operator working. in modern versions of sage the __IP variable
+        //has been removed
+        if (enable)
+            evaluateExpression("sage.misc.latex.pretty_print_default(true);_;__IP.outputcache()", Cantor::Expression::DeleteOnFinish);
+        else
+            evaluateExpression("sage.misc.latex.pretty_print_default(false);_;__IP.outputcache()", Cantor::Expression::DeleteOnFinish);
+    }else
+    {
+        if (enable)
+            evaluateExpression("sage.misc.latex.pretty_print_default(true)", Cantor::Expression::DeleteOnFinish);
+        else
+            evaluateExpression("sage.misc.latex.pretty_print_default(false)", Cantor::Expression::DeleteOnFinish);
+    }
 }
 
 Cantor::CompletionObject* SageSession::completionFor(const QString& command, int index)
@@ -305,5 +366,9 @@ QSyntaxHighlighter* SageSession::syntaxHighlighter(QObject* parent)
     return new SageHighlighter(parent);
 }
 
+bool SageSession::inLegacyMode()
+{
+  return m_inLegacyMode;
+}
 
 #include "sagesession.moc"
